@@ -74,12 +74,16 @@ class MaskedLM:
         self.mask_token = self.tokenizer.mask_token
 
         # GPU setup
+        self.device = self.model.device
         if device_map is None:
             num_gpus = torch.cuda.device_count() if num_gpus is None else num_gpus
-            if num_gpus > 0:
+            if num_gpus == 1:
+                self.model.to('cuda')
+                self.device = self.model.device
+            elif num_gpus > 1:
                 self.model = torch.nn.DataParallel(self.model) if num_gpus > 1 else self.model
                 self.model.to('cuda')
-        logging.info(f'\t * model is loaded on: {self.model.device}')
+                self.device = self.model.module.device
         self.model.eval()
 
     def get_perplexity(self, input_texts: str or List, batch: int = None):
@@ -141,7 +145,7 @@ class MaskedLM:
         with torch.no_grad():
             for s, e in tqdm(batch_id):
                 _encode = data[s:e]
-                _encode = {k: torch.cat([o[k] for o in _encode], dim=0).to(self.model.device) for k in _encode[0].keys()}
+                _encode = {k: torch.cat([o[k] for o in _encode], dim=0).to(self.device) for k in _encode[0].keys()}
                 labels = _encode.pop('labels')
                 output = self.model(**_encode, return_dict=True)
                 prediction_scores = output['logits']
